@@ -2,14 +2,13 @@
 /**
  * addacl.php
  *
- * Copyright (c) 1999-2003 Alexandros Vellis <avel@noc.uoa.gr>
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * @package plugins
  * @subpackage useracl
- */
-
-/**
+ * @copyright 2003-2004 Alexandros Vellis <avel@noc.uoa.gr>
+ * @version $Id: addacl.php,v 1.3 2004/08/09 13:07:26 avel Exp $
+ *
  * This file can be called from other Squirrelmail plugins or pages, which want
  * to provide a direct link to add ACLs to a predefined username.
  *
@@ -25,11 +24,13 @@ require_once(SM_PATH . 'include/validate.php');
 require_once(SM_PATH . 'functions/global.php');
 require_once(SM_PATH . 'functions/imap.php');
 require_once(SM_PATH . 'functions/display_messages.php');
+
+$prev = bindtextdomain ('useracl', SM_PATH . 'plugins/useracl/locale');
+textdomain ('useracl');
 require_once(SM_PATH . 'plugins/useracl/config.php');
 require_once(SM_PATH . 'plugins/useracl/imap_acl.php');
 require_once(SM_PATH . 'plugins/useracl/functions.php');
 require_once(SM_PATH . 'plugins/useracl/html.php');
-// require_once(SM_PATH . 'plugins/directory/html.php');
 
 sqgetGlobalVar('key',          $key,           SQ_COOKIE);
 sqgetGlobalVar('username',     $username,      SQ_SESSION);
@@ -66,21 +67,19 @@ if(sqimap_capability($imapConnection, 'ACL') == false ) {
 $boxes = sqimap_mailbox_list($imapConnection);
 sqimap_logout($imapConnection);
 
-$prev = bindtextdomain ('useracl', SM_PATH . 'plugins/useracl/locale');
-textdomain ('useracl');
 
 if ($compose_new_win == '1') {
 	displayHtmlHeader(_("Add New User Permission"), '', false);
 } else {
 	$prev = bindtextdomain ('squirrelmail', SM_PATH . 'locale');
 	textdomain ('squirrelmail');
-
 	displayPageHeader($color, $mailbox);
 
-	$prev = bindtextdomain ('useracl', SM_PATH . 'plugins/useracl/locale');
-	textdomain ('useracl');
 }
 
+$prev = bindtextdomain ('useracl', SM_PATH . 'plugins/useracl/locale');
+textdomain ('useracl');
+
 
 
 useracl_html_printheader( _("Add New User Permission") );
@@ -94,7 +93,7 @@ if(isset($myuser)){
 }
 print '" method="post">';
 print '<table width="100%" border="0" >';
-useracl_print_table_header();
+useracl_print_table_header(true);
 useracl_print_addnew_separate($mybox, $myuser);
 print '</table>';
 print '</form>';
@@ -114,6 +113,4 @@ if ($compose_new_win == '1') {
 
 useracl_html_printfooter();
 
-
-
 ?>
