@@ -2,14 +2,13 @@
 /**
  * useracl.php
  *
- * Copyright (c) 1999-2003 Alexandros Vellis <avel@noc.uoa.gr>
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * @package plugins
  * @subpackage useracl
- */
-
-/**
+ * @copyright 2003-2004 Alexandros Vellis <avel@noc.uoa.gr>
+ * @version $Id: config_sample.php,v 1.7 2005/02/28 13:03:05 avel Exp $
+ *
  * Configuration File
  */
 
@@ -20,9 +19,10 @@
  * Currently supported schemes:
  * - 'mailbox': User must have an existing INBOX (not implemented yet)
  * - 'ldap': User must exist in LDAP
+ * - 'sql': Check table in SQL database
  * - 'none': No check is performed
  *
- * @var string One of 'mailbox', 'ldap' or 'none'
+ * @var string One of 'mailbox', 'ldap', 'sql' or 'none'
  */
  
 $check_user_method = 'none';
@@ -46,6 +46,15 @@ $ldap_server_no = 0;
 $useracl_root_username = 'cyrusadmin';
 $useracl_root_password = 'secret';
 
+/**
+ * If check user method is "SQL", then specify the database DSN
+ * to connect to and the table and field to check.
+ */
+$useracl_sql_dsn = 'pgsql://squirrelmail:qwerty99@unix(/tmp)/squirrelmail';
+$useracl_sql_table = 'accounts';
+$useracl_sql_username_field = 'id';
+
+
 /**
  * Restrict only to INBOX.* Folders. Only works for Cyrus Normal Namespace.
  * This is a hack until we properly support NAMESPACE.
@@ -65,7 +74,6 @@ $show_ldap_cn = false;
  */
 $useracl_enable_notify = true;
 
-
 /**
  * Show iconic image submit buttons?
  * @var boolean
