@@ -2,14 +2,13 @@
 /**
  * setup.php
  *
- * Copyright (c) 1999-2004 Alexandros Vellis <avel@noc.uoa.gr>
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * @package plugins
  * @subpackage useracl
- */
-
-/**
+ * @copyright 2003-2004 Alexandros Vellis <avel@noc.uoa.gr>
+ * @version $Id: setup.php,v 1.10 2005/07/15 14:49:35 avel Exp $
+ *
  * Squirrelmail Plugin Functions
  */
 
@@ -28,7 +27,7 @@ function useracl_menuline() {
 	bindtextdomain('useracl', SM_PATH . 'plugins/useracl/locale');
 	textdomain ('useracl');
 
-   	displayInternalLink('plugins/useracl/useracl.php', _("Shares") ,'right');
+   	displayInternalLink('plugins/useracl/useracl.php', _("Shares"));
 	echo "&nbsp;&nbsp\n";
 
 	bindtextdomain('squirrelmail', SM_PATH . 'locale');
@@ -39,7 +38,7 @@ function useracl_menuline() {
  * Version information
  */
 function useracl_version() {
-	return '1.2';
+	return '2.0';
 }
  
 ?>
