@@ -2,14 +2,13 @@
 /**
  * useracl.php
  *
- * Copyright (c) 1999-2004 Alexandros Vellis <avel@noc.uoa.gr>
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * @package plugins
  * @subpackage useracl
- */
-
-/**
+ * @copyright 2003-2004 Alexandros Vellis <avel@noc.uoa.gr>
+ * @version $Id: useracl.php,v 1.18 2005/02/28 12:52:55 avel Exp $
+ *
  * Main routine - Business and Presentation Logic (GUI) are in here
  */
 
@@ -20,6 +19,8 @@ require_once(SM_PATH . 'include/validate.php');
 require_once(SM_PATH . 'functions/global.php');
 require_once(SM_PATH . 'functions/imap.php');
 require_once(SM_PATH . 'functions/display_messages.php');
+$prev = bindtextdomain ('useracl', SM_PATH . 'plugins/useracl/locale');
+textdomain ('useracl');
 require_once(SM_PATH . 'plugins/useracl/config.php');
 require_once(SM_PATH . 'plugins/useracl/imap_acl.php');
 require_once(SM_PATH . 'plugins/useracl/functions.php');
@@ -31,6 +32,8 @@ sqgetGlobalVar('username',     $username,      SQ_SESSION);
 sqgetGlobalVar('onetimepad',   $onetimepad,    SQ_SESSION);
 sqgetGlobalVar('delimiter',    $delimiter,     SQ_SESSION);
 
+sqgetGlobalVar('perm_check',    $perm_check,     SQ_POST);
+
 if(isset($_POST['mbox'])) {
 	$mbox = urldecode($_POST['mbox']);
 }
@@ -101,8 +104,6 @@ if(sqimap_capability($imapConnection, 'ACL') == false ) {
 	exit;
 }
 
-$prev = bindtextdomain ('useracl', SM_PATH . 'plugins/useracl/locale');
-textdomain ('useracl');
 
 /*  ----- Handle POST Actions -----  */
 
@@ -125,13 +126,26 @@ if(isset($_POST['update_all'])) {
 	/* Update All */
 	$all_users = $_POST['all_users'];
 
-	for($i=0;$i<count($all_users);$i++){
+	for($i=0;$i<count($all_users);$i++){ /* Users Loop */
 		$user = $all_users[$i];
-		$permission = $_POST['perm_radio'][$user];
-		if($perm_prev[$user] != $permission) {
-			$re = set_permission($imapConnection, $mbox, $user, $permission);
+		$old = $perm_prev[$user];
+
+		$perm_new[$user] = '';
+		foreach($acl as $a => $info) { /* ACLs loop */
+			if(isset($perm_check[$user][$a])) {
+				$perm_new[$user] .= $info['acl'];
+			}
+		}
+	}
+
+	foreach($perm_prev as $user=>$perm_old) {
+		if($perm_old != $perm_new[$user]) {
+			$re = set_permission($imapConnection, $mbox, $user, '', $perm_new[$user]);
 			if($notify) {
-				$notify_users[] = array('user' => $user, 'permission' => $permission, 'mailbox' => $mbox, 'type' => 'change');
+				$notify_users[] = array('user' => $user,
+					'permission' => $perm_new[$user],
+					'mailbox' => $mbox,
+					'type' => 'change');
 			}
 		}
 	}
@@ -146,84 +160,48 @@ if(isset($_POST['update_all'])) {
 		$errormsg[] = sprintf (_("No changes in permissions for folder %s"), imap_utf7_decode_local($mbox));
 	}
 
-
-} elseif(isset($_POST['update'])) {
-	/* Update Single */
-	$user_sent = array_keys($_POST['update']);
-	$user = $user_sent[0];
-	$permission = $_POST['perm_radio'][$user];
-	
-	if($perm_prev[$user] != $permission) {
-		$re = set_permission($imapConnection, $mbox, $user, $permission);
-		if($notify) {
-			$notify_users[] = array('user' => $user, 'permission' => $permission, 'mailbox' => $mbox, 'type'=>'change');
-		}
-	}
-
-	if(isset($re)) {
-		if($re) {
-			$successmsg[] = sprintf( _("Successfully changed permissions for folder %s"), imap_utf7_decode_local($mbox));
-		} else {
-			$errormsg[] = sprintf( _("Failed to change permissions for folder %s"), imap_utf7_decode_local($mbox));
-		}
-	} else {
-		$errormsg[] = sprintf (_("No changes in permissions for folder %s"), imap_utf7_decode_local($mbox));
-	}
-		
-
-} elseif(isset($_POST['delete_checked'])) {
-	/* Delete Checked Permissions */
-	$delete_checked = $_POST['delete_checked'];
-
-	for($i=0;$i<count($delete_checked);$i++){
-		$user = $delete_checked[$i];
-		if( sqimap_deleteacl($imapConnection, urldecode($mbox), urldecode($user))) {
-			$successmsg[] = sprintf( _("Successfully changed permissions for folder %s"), imap_utf7_decode_local($mbox));
-		} else {
-			$errormsg[] = sprintf( _("Failed to change permissions for folder %s"), imap_utf7_decode_local($mbox));
-		}
-	}
-
 }
 
 if(isset($adduser) || (isset($_POST['update_all']) && isset($newuser))) {
 
 	/* Add New User */
-	$user = trim($_POST['newuser']);
+	$user = trim($newuser);
+
 	if(strlen($user)) {
-		$permission = $_POST['new_user_perm_radio'];
+		$new_user_perm_check = $_POST['new_user_perm_check'];
+		$new_user_perm = '';
+		foreach($acl as $a => $info) { /* ACLs loop */
+			if(isset($new_user_perm_check[$a])) {
+				$new_user_perm .= $info['acl'];
+			}
+		}
 	
 		if($user == $username) {
 			/* Myself */
 			$errormsg[] = _("Cannot modify permissions on your own folder; you will always have full rights on your folders.");
 
-		} elseif(isset($perm_prev[$user]) && $perm_prev[$user] == $permission) {
+		} elseif(isset($perm_prev[$user]) && $perm_prev[$user] == $new_user_perm) {
 			/* Same user, same permission */
-			$neutralmsg[] = sprintf(_("User %s already has %s permission for folder %s."),
-			  $user, _(ucfirst($permission)), imap_utf7_decode_local($mbox));
+			$neutralmsg[] = sprintf (_("No changes in permissions for user %s"), $user);
 		
-		} elseif(isset($perm_prev[$user]) && $perm_prev[$user] != $permission) {
+		} elseif(isset($perm_prev[$user]) && $perm_prev[$user] != $new_user_perm) {
 			/* Same user, changed permission! */
-			if($ret = set_permission($imapConnection, $mbox, $user, $permission)) {
-				$successmsg[] = sprintf( _("User %s has been given %s permisssion for folder %s."),
-				  $user, _(ucfirst($permission)), imap_utf7_decode_local($mbox));
-				$notify_users[] = array('user' => $user, 'permission' => $permission, 'mailbox' => $mbox, 'type'=>'change');
+			if($ret = set_permission($imapConnection, $mbox, $user, '', $new_user_perm)) {
+				$successmsg[] = sprintf( _("Successfully changed permissions for folder %s"), imap_utf7_decode_local($mbox));
+				$notify_users[] = array('user' => $user, 'permission' => $new_user_perm, 'mailbox' => $mbox, 'type'=>'change');
 			} else {
-				$errormsg[] = sprintf( _("Failed to give user %s %s permission for folder %s."),
-				  $user, _(ucfirst($permission)), imap_utf7_decode_local($mbox));
+				$errormsg[] = sprintf( _("Failed to change permissions for folder %s"), imap_utf7_decode_local($mbox));
 			}
 
-		} elseif($ret = set_permission($imapConnection, $mbox, $user, $permission)) {
+		} elseif($ret = set_permission($imapConnection, $mbox, $user, '', $new_user_perm)) {
 			/* Successfully added acl for user */
-			$successmsg[] = sprintf( _("User %s has been given %s permisssion for folder %s."),
-			  $user, _(ucfirst($permission)), imap_utf7_decode_local($mbox));
-			$notify_users[] = array('user' => $user, 'permission' => $permission, 'mailbox' => $mbox, 'type'=>'new');
+			$successmsg[] = sprintf( _("Successfully changed permissions for user %s."), $user);
+			$notify_users[] = array('user' => $user, 'permission' => $new_user_perm, 'mailbox' => $mbox, 'type'=>'new');
 
 		} else {
 			/* User does not exist */
-			$errormsg[] = sprintf( _("Failed to give user %s %s permission for folder %s."),
-			  $user, _(ucfirst($permission)), imap_utf7_decode_local($mbox));
-			$errormsg[] = _("Specified user does not exist.");
+			$errormsg[] = sprintf( _("Failed to change permissions for user %s."), $user) .
+			  ' ' . _("Specified user does not exist.");
 		}
 	}
 }
@@ -273,9 +251,10 @@ foreach($boxes as $no=>$box) {
 
 	$mb = $box['unformatted'];
 
-	/* Get ACLs only for subfolders of INBOX */
+	/* Get ACLs only for subfolders of INBOX  and INBOX itself - in case
+	 * there is an ACL there too. */
 	if( ($useracl_only_inbox == false) ||
-	    (strstr($mb, 'INBOX') && $mb != 'INBOX' ) ) {
+	    (strstr($mb, 'INBOX')) ) {
 		sqimap_getacl($imapConnection, $mb, $out);
 		if(array_key_exists($username, $out)) {
 			unset($out[$username]);
@@ -286,7 +265,6 @@ foreach($boxes as $no=>$box) {
 $perm_array = create_human_readable_permarray($perm);
 sqimap_logout($imapConnection);
 
-
 if(isset($ldap)) {
 	/* We don't require directory plugin any more. Hopefully. */
 	require_once(SM_PATH . 'plugins/useracl/ldap.php');
@@ -352,6 +330,11 @@ if(isset($ldap)) {
 		if(isset($entries[$i]['mail'][0])) {
 			$mails[$entries[$i]['uid'][0]] = $entries[$i]['mail'][0];
 		}
+
+		/* Also fill in translated names for anonymous and anyone */
+		$names['anyone'] = '<em>'. _("Anyone") .'</em>';
+		$names['anonymous'] = '<em>'. _("Anonymous") .'</em>';
+
 	}
 	ldap_close($ldap);
 }
@@ -363,12 +346,14 @@ if(isset($ldap)) {
  * If there is mail notification to send, display the reminder/notice.
  */
 if(isset($notify_users) && $notify) {
-
 	require_once(SM_PATH . 'class/deliver/Deliver.class.php');
 	require_once(SM_PATH . 'functions/mime.php');
 	require_once(SM_PATH . 'functions/identity.php');
 
 	foreach($notify_users as $n=>$info) {
+		if($info['user'] == 'anyone' || $info['user'] == 'anonymous') {
+			continue;
+		}
 		$notifyMessage = new Message();
 		$rfc822_header = new Rfc822Header();
 		$notifyMessage->rfc822_header = $rfc822_header;
@@ -381,7 +366,7 @@ if(isset($notify_users) && $notify) {
 		} else {
 			/* Mail in the form of: userid@domain. Domain is the
 			 * default domain taken from config/config.php. */
-			$send_to = $info['user']. $domain;
+			$send_to = $info['user']. '@' . $domain;
 		}
 
 		if($info['type'] == 'change' && $info['permission'] == 'none') {
@@ -472,9 +457,6 @@ if ($compose_new_win == '1' && isset($_GET['addacl'])) {
 	textdomain ('squirrelmail');
 
 	displayPageHeader($color, '');
-
-	$prev = bindtextdomain ('useracl', SM_PATH . 'plugins/useracl/locale');
-	textdomain ('useracl');
 }
 
 $prev = bindtextdomain ('useracl', SM_PATH . 'plugins/useracl/locale');
@@ -508,7 +490,6 @@ useracl_html_printheader( _("User Permissions") );
 useracl_html_print_all_sections_start();
 
 foreach($boxes as $no=>$box) {
-
 	$mbox = $box['unformatted'];
 
 	if (isset($_GET['addacl'])) {
@@ -517,7 +498,7 @@ foreach($boxes as $no=>$box) {
 		}
 	}
 
-	if(isset($perm_array[$mbox]) || isset($addacl)) {
+	if( (isset($perm[$mbox]) && sizeof($perm[$mbox]) > 0 ) || isset($addacl)) {
 
 	   	$formname = "form_".str_replace(array('.','%', '-') , array('_','_','_'),
 			rawurlencode($mbox));
@@ -534,10 +515,15 @@ foreach($boxes as $no=>$box) {
 		print '<input type="hidden" name="mbox" value="'.urlencode($mbox).'" />';
 		print '<table width="100%" border="0" >';
 		useracl_print_table_header();
-		if(isset($perm_array[$mbox]))
-			useracl_print_array($perm_array[$mbox], $mbox);
-		else
+
+		if(isset($perm[$mbox]) && sizeof($perm[$mbox]) > 0) {
+			useracl_print_array($perm[$mbox], $mbox);
+		/*
+		} else {
 			useracl_print_array(array(), $mbox);
+			*/
+		}
+			
 		useracl_print_addnew($formname);
 		useracl_print_table_footer();
 		print '</table>';
@@ -580,7 +566,7 @@ useracl_html_print_all_sections_end();
 $prev = bindtextdomain ('squirrelmail', SM_PATH . 'locale');
 textdomain ('squirrelmail');
 if ($compose_new_win == '1' && isset($_GET['addacl'])) {
-	print '<INPUT TYPE="BUTTON" NAME="Close" onClick="return self.close()" VALUE='._("Close").'></TD></TR>'."\n";
+	print '<input type="button" name="Close" onClick="return self.close()" value='._("Close").'></td></tr>'."\n";
 }
 
 
